
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2018-08-23T15:00:41-0500",
 "dirty": false,
 "error": null,
 "full-revisionid": "7ae46fc4d2ae1a9bb056ae97f559f3d62422c1e2",
 "version": "0.3.1"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
